cis_config: Member List

cis_config

comm_t Member List

This is the complete list of members for comm_t, including all inherited members.

address | comm_t |
always_send_header | comm_t |
direction | comm_t |
handle | comm_t |
index_in_register | comm_t |
info | comm_t |
is_file | comm_t |
is_work_comm | comm_t |
last_send | comm_t |
maxMsgSize | comm_t |
name | comm_t |
recv_eof | comm_t |
reply | comm_t |
sent_eof | comm_t |
serializer | comm_t |
type | comm_t |
used | comm_t |
valid | comm_t |